==> mac_pyxa-0.0.8-py3-none-any.whl: PyXA/apps/__init__.py <==
application_classes = {
    # "invocation": ("module_name", "application_object_name")
    ### First Party Scriptable Apps
    "finder": ("Finder", "XAFinderApplication"),
    "safari": ("Safari", "XASafariApplication"),
    "music": ("Music", "XAMusicApplication"),
    "reminders": ("Reminders", "XARemindersApplication"),
    "notes": ("Notes", "XANotesApplication"),
    "messages": ("Messages", "XAMessagesApplication"),
    "calendar": ("Calendar", "XACalendarApplication"),
    "textedit": ("TextEdit", "XATextEditApplication"),
    "pages": ("Pages", "XAPagesApplication"),
    "system events": ("SystemEvents", "XASystemEventsApplication"),
    "systemevents": ("SystemEvents", "XASystemEventsApplication"),
    "terminal": ("Terminal", "XATerminalApplication"),
    "preview": ("Preview", "XAPreviewApplication"),
    "tv": ("TV", "XATVApplication"),
    "contacts": ("Contacts", "XAContactsApplication"),
    "shortcuts": ("Shortcuts", "XAShortcutsApplication"),
    "shortcuts events": ("Shortcuts", "XAShortcutsApplication"),
    "photos": ("PhotosApp", "XAPhotosApplication"),
    "system preferences": ("SystemPreferences", "XASystemPreferencesApplication"),
    "keynote": ("Keynote", "XAKeynoteApplication"),
    "mail": ("Mail", "XAMailApplication"),
    "automator": ("Automator", "XAAutomatorApplication"),
    "console": ("Console", "XAConsoleApplication"),
    "font book": ("FontBook", "XAFontBookApplication"),
    "quicktime player": ("QuickTimePlayer", "XAQuickTimeApplication"),
    "numbers": ("Numbers", "XANumbersApplication"),

    ### First Party Non-scriptable Apps
    "calculator": ("Calculator", "XACalculatorApplication"),
    "dictionary": ("Dictionary", "XADictionaryApplication"),
    "maps": ("Maps", "XAMapsApplication"),
    "stocks": ("Stocks", "XAStocksApplication"),

    ### Third Party Scriptable Apps
    # Chromium
    "chromium": ("Chromium", "XAChromiumApplication"),
    "brave browser": ("Chromium", "XAChromiumApplication"),
    "microsoft edge": ("Chromium", "XAChromiumApplication"),
    "google chrome": ("Chromium", "XAChromiumApplication"),
    "opera": ("Chromium", "XAChromiumApplication"),
    "vivaldi": ("Chromium", "XAChromiumApplication"),
    "blisk": ("Chromium", "XAChromiumApplication"),
    "iridium": ("Chromium", "XAChromiumApplication"),

    "alfred": ("Alfred", "XAAlfredApplication"),
    "drafts": ("Drafts", "XADraftsApplication"),
    "hammerspoon": ("Hammerspoon", "XAHammerspoonApplication"),

    "vlc": ("VLC", "XAVLCApplication"),
}

==> mac_pyxa-0.1.0.1-py3-none-any.whl: PyXA/apps/__init__.py <==
application_classes = {
    # "invocation": ("module_name", "application_object_name")
    ### First Party Scriptable Apps
    "finder": ("Finder", "XAFinderApplication"),
    "safari": ("Safari", "XASafariApplication"),
    "music": ("Music", "XAMusicApplication"),
    "reminders": ("Reminders", "XARemindersApplication"),
    "notes": ("Notes", "XANotesApplication"),
    "messages": ("Messages", "XAMessagesApplication"),
    "calendar": ("Calendar", "XACalendarApplication"),
    "textedit": ("TextEdit", "XATextEditApplication"),
    "pages": ("Pages", "XAPagesApplication"),
    "terminal": ("Terminal", "XATerminalApplication"),
    "preview": ("Preview", "XAPreviewApplication"),
    "tv": ("TV", "XATVApplication"),
    "contacts": ("Contacts", "XAContactsApplication"),
    "shortcuts": ("Shortcuts", "XAShortcutsApplication"),
    "shortcuts events": ("Shortcuts", "XAShortcutsApplication"),
    "photos": ("PhotosApp", "XAPhotosApplication"),
    "system preferences": ("SystemPreferences", "XASystemPreferencesApplication"),
    "system settings": ("SystemPreferences", "XASystemPreferencesApplication"),
    "keynote": ("Keynote", "XAKeynoteApplication"),
    "mail": ("Mail", "XAMailApplication"),
    "automator": ("Automator", "XAAutomatorApplication"),
    "console": ("Console", "XAConsoleApplication"),
    "font book": ("FontBook", "XAFontBookApplication"),
    "quicktime player": ("QuickTimePlayer", "XAQuickTimeApplication"),
    "numbers": ("Numbers", "XANumbersApplication"),
    "script editor": ("ScriptEditor", "XAScriptEditorApplication"),
    "system events": ("SystemEvents", "XASystemEventsApplication"),
    "image events": ("ImageEvents", "XAImageEventsApplication"),

    ### First Party Non-scriptable Apps
    "calculator": ("Calculator", "XACalculatorApplication"),
    "dictionary": ("Dictionary", "XADictionaryApplication"),
    "maps": ("Maps", "XAMapsApplication"),
    "stocks": ("Stocks", "XAStocksApplication"),

    ### Third Party Scriptable Apps
    # Chromium
    "chromium": ("Chromium", "XAChromiumApplication"),
    "brave browser": ("Chromium", "XAChromiumApplication"),
    "microsoft edge": ("Chromium", "XAChromiumApplication"),
    "google chrome": ("Chromium", "XAChromiumApplication"),
    "opera": ("Chromium", "XAChromiumApplication"),
    "vivaldi": ("Chromium", "XAChromiumApplication"),
    "blisk": ("Chromium", "XAChromiumApplication"),
    "iridium": ("Chromium", "XAChromiumApplication"),

    "alfred": ("Alfred", "XAAlfredApplication"),
    "drafts": ("Drafts", "XADraftsApplication"),
    "hammerspoon": ("Hammerspoon", "XAHammerspoonApplication"),
    "rstudio": ("RStudio", "XARStudioApplication"),
    "iterm": ("iTerm", "XAiTermApplication"),

    "vlc": ("VLC", "XAVLCApplication"),
    "fantastical": ("Fantastical", "XAFantasticalApplication"),
    "omnioutliner": ("OmniOutliner", "XAOmniOutlinerApplication"),
    "spotify": ("Spotify", "XASpotifyApplication"),
    "flow": ("Flow", "XAFlowApplication"),
    "bike": ("Bike", "XABikeApplication"),
    "adobe acrobat reader": ("AcrobatReader", "XAAcrobatReaderApplication"),
    "cardhop": ("Cardhop", "XACardhopAppplication"),
    "amphetamine": ("Amphetamine", "XAAmphetamineApplication"),
}
